/*
 * ClipperOptionPane.java
 * Copyright (c) 1999-2000 Andre Kaplan, Chris Laird
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import javax.swing.*;
import javax.swing.border.EmptyBorder;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.jedit.MiscUtilities;
import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.OptionPane;


public class ClipperOptionPane extends AbstractOptionPane
{
    private JButton    pickDirectory;
    private JTextField clipperDirectory;


    public ClipperOptionPane() {
        super("clipper");
    }


    protected void _init() {
        setLayout(new BorderLayout());
        setBorder(new EmptyBorder(5,5,5,5));
        JPanel northPanel = new JPanel(new BorderLayout(5,0));
        northPanel.setOpaque(false);
        JPanel labelPanel = new JPanel(new GridLayout(0,1));
        labelPanel.setOpaque(false);
        JPanel fieldPanel = new JPanel(new GridLayout(0,1));
        fieldPanel.setOpaque(false);
        northPanel.add(labelPanel, BorderLayout.WEST);
        northPanel.add(fieldPanel, BorderLayout.CENTER);
        add(northPanel, BorderLayout.NORTH);

        JLabel label = new JLabel(jEdit.getProperty(
            ClipperPlugin.OPTION_PREFIX + "clipper-directory"));
        labelPanel.add(label);
        JPanel directoryPanel = new JPanel(new BorderLayout(5,0));
        clipperDirectory = new JTextField();
        clipperDirectory.setText(jEdit.getProperty(
            ClipperPlugin.PROPERTY_PREFIX + "clipLibraryDirectory.0"));
        pickDirectory = new JButton(jEdit.getProperty(
            ClipperPlugin.OPTION_PREFIX + "choose-directory"));
        pickDirectory.addActionListener(new PickDirectory());
        directoryPanel.add(clipperDirectory, BorderLayout.CENTER);
        directoryPanel.add(pickDirectory, BorderLayout.EAST);
        fieldPanel.add(directoryPanel);
    }


    protected void _save() {
        jEdit.setProperty(
            ClipperPlugin.PROPERTY_PREFIX + "clipLibraryDirectory.0",
            clipperDirectory.getText()
        );
    }


    private class PickDirectory implements ActionListener
    {
        public PickDirectory() {}


        public void actionPerformed(ActionEvent evt) {
            JFileChooser chooser = new JFileChooser();
            chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
            int retVal = chooser.showDialog(
                ClipperOptionPane.this,
                jEdit.getProperty(
                    ClipperPlugin.OPTION_PREFIX + "choose-directory"
                )
            );

            if (retVal == JFileChooser.APPROVE_OPTION) {
                File file = chooser.getSelectedFile();
                if (file != null) {
                    try {
                        String dirName = file.getCanonicalPath();
                        ClipperOptionPane.this.clipperDirectory.setText(dirName);
                    } catch(IOException e) {
                        // shouldn't happen
                    }
                }
            }
        }
    }
}
