/*
 * ClipperPlugin.java
 * Copyright (c) 1999-2000 Andre Kaplan, Chirs Laird
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


import java.util.Vector;

import javax.swing.JDialog;

import org.gjt.sp.jedit.EBMessage;
import org.gjt.sp.jedit.EBPlugin;
import org.gjt.sp.jedit.EditBus;
import org.gjt.sp.jedit.GUIUtilities;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.jedit.gui.DockableWindow;
import org.gjt.sp.jedit.gui.OptionsDialog;
import org.gjt.sp.jedit.msg.CreateDockableWindow;
import org.gjt.sp.util.Log;


/**
 * The <CODE>Plugin</CODE> implementation for the Clipper.
 */
public class ClipperPlugin extends EBPlugin
{
    /**
     * The 'name' of the dockable window.
    **/
    public static final String DOCKABLE_NAME = "clipper-dockable";


    /** All Clipper's properties have names that start with this string */
    public static final String PROPERTY_PREFIX = "plugin.Clipper.";


    /** All Clipper's options have names that start with this string */
    public static final String OPTION_PREFIX = "options.clipper.";


    /** The property that records the last clip library used */
    public static final String CURRENT_CLIPLIBRARY = "lastClipLibrary";


    /**
     * The character in cliplibrary files that marks where the cursor should be
     * placed when that clip is inserted
     */
    public static final char CURSOR_MARKER = '|';


    /**
     * Starts the plugin.
    **/
    public void start() {
        EditBus.addToNamedList(DockableWindow.DOCKABLE_WINDOW_LIST, DOCKABLE_NAME);
    }


    /**
     * Stops the plugin.
    **/
    public void stop() {}


    /**
     * Clipper menu
    **/
    public void createMenuItems(Vector menuItems) {
        menuItems.addElement(GUIUtilities.loadMenuItem("clipper.toggle-dockable"));
    }


    /**
     * Clipper option pane
    **/
    public void createOptionPanes(OptionsDialog optionsDialog) {
        optionsDialog.addOptionPane(new ClipperOptionPane());
    }


    /**
     * Handles CreateDockableWindow messages
    **/
    public void handleMessage(EBMessage message)
    {
        if (message instanceof CreateDockableWindow) {
            this.handleCreateDockableWindow((CreateDockableWindow) message);
        }
    }


    private void handleCreateDockableWindow(CreateDockableWindow message) {
        if (message.getDockableWindowName()
                .equals(ClipperPlugin.DOCKABLE_NAME)
        ) {
            message.setDockableWindow(new ClipperDockable(message.getView()));
        }
    }
}
